@@ -4,19 +4,15 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
     
     verify.truthTable(mydata, outcome, conditions, inside, complete, show.cases)
     
-    no.of.conditions <- ncol(mydata) - 1
-    
-     # if the outcome variable is not the last one, it will be placed the last
-    if (which(colnames(mydata) %in% outcome) != ncol(mydata)) {
-        outcm.name <- colnames(mydata)[which(colnames(mydata) == outcome)]
-        outcm   <- mydata[,  which(colnames(mydata) == outcome)]
-        mydata  <- mydata[, -which(colnames(mydata) == outcome)]
-        mydata <- cbind(mydata, outcm)
-        colnames(mydata)[ncol(mydata)] <- outcm.name
+    if (all(conditions == c(""))) {
+        conditions <- names(mydata)[-which(names(mydata)==outcome)]
         }
+    mydata <- mydata[, c(conditions, outcome)]
+    
+    nofconditions <- length(conditions)
     
      # the data MUST begin with 0 and MUST be incremented by 1 for each level
-    noflevels <- apply(mydata[, 1:no.of.conditions], 2, max) + 1
+    noflevels <- apply(mydata[, conditions], 2, max) + 1
     
     if (inside) complete <- FALSE
     
@@ -27,7 +23,7 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
                        "Printing it on the screen is unmeaningful.", "\n\n", sep=""), call. = FALSE)
             }
          # the "old" way, which at the time it was 10 times faster than the former code
-         # tt <- as.matrix(expand.grid(rep(list(c(0,1)), no.of.conditions))[, no.of.conditions:1])
+         # tt <- as.matrix(expand.grid(rep(list(c(0,1)), nofconditions))[, nofconditions:1])
         
          # the new way, which is 5.5 times faster than expand.grid for binary data :))
         tt <- createMatrix(noflevels)
@@ -35,7 +31,7 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
         line.tt <- seq_len(prod(noflevels))
         }
     else {
-        tt <- unique(mydata[, 1:no.of.conditions])
+        tt <- unique(mydata[, conditions])
         mbase <- c(rev(cumprod(rev(noflevels))), 1)[-1]
         line.tt <- colSums(apply(tt, 1, function(x) x*mbase)) + 1
         tt <- tt[order(line.tt), ]               
@@ -49,7 +45,7 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
     colnames(tt)[(ncol(tt) - 1):ncol(tt)] <- c("freq0", "freq1")
     tt <- as.data.frame(tt)
     
-    line.mydata <- as.character(colSums(apply(mydata[, 1:no.of.conditions], 1, function(x) x*mbase)) + 1)
+    line.mydata <- as.character(colSums(apply(mydata[, conditions], 1, function(x) x*mbase)) + 1)
     column.tt <- ncol(mydata) + mydata[, outcome] + 1
     
     for (i in 1:nrow(mydata)) {
@@ -83,11 +79,11 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
             if (any(tt[, outcome] == "?")) {tt <- tt[-which(tt[, outcome] == "?"), ]}
             }
         var.names <- colnames(tt)[1:ncol(mydata)]
-        colnames(tt)[1:no.of.conditions] <- LETTERS[1:no.of.conditions]
+        colnames(tt)[1:nofconditions] <- LETTERS[1:nofconditions]
         colnames(tt)[ncol(mydata)] <- "OUT"
         cat("\n", sep="")
-        for (i in 1:no.of.conditions) {cat("    ", paste(LETTERS[i], ": ", sep=""), var.names[i], "\n", sep="")}
-        cat("  ", "OUT: ", var.names[no.of.conditions + 1], "\n", sep="")
+        for (i in 1:nofconditions) {cat("    ", paste(LETTERS[i], ": ", sep=""), var.names[i], "\n", sep="")}
+        cat("  ", "OUT: ", var.names[nofconditions + 1], "\n", sep="")
         cat("freq0: frequency of outcome equal to 0\nfreq1: frequency of outcome equal to 1\n", sep="")
         if (show.cases) cat("cases: case names\n", sep="")
         cat("\n", sep="")
